@@ -18,13 +18,13 @@ from sphinx.util import logging, split_into, docutils
 from sphinx.writers import html5
 
 import sphindexer as idxr
-from sphindexer.rack import UNIT_CLSF, UNIT_TERM, UNIT_SBTM
+from sphindexer.rack import UNIT_TERM, UNIT_SBTM, Convert
 
 
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.31.4' # 2022-02-24
+__version__ = '0.32.0' # 2022-02-28
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 
@@ -71,12 +71,12 @@ _a2z = re.compile(r'[a-zA-Z]')
 
 #「かな|単語^オプション」の「オプション」の変換用
 class _s2i:
-    each_together = {
+    ruby_on = {
         'a': 1, 'b': 2, 'c': 3, 'd': 4, 'e': 5,
         'f': 6, 'g': 7, 'h': 8, 'i': 9
     }
 
-    step_by_step = {
+    ruby_off = {
         'q': 1, 'r': 2, 's': 3, 't': 4, 'u': 5,
         'v': 6, 'w': 7, 'x': 8, 'y': 9
     }
@@ -109,26 +109,31 @@ def make_html_with_ruby(word: str, kana: str) -> str:
 
 def make_specific_by_parsing_option(word, kana, option):
     rtn, opt, t_s, t_end, r_s, r_end = [], list(option), 0, 0, 0, 0
+    slen, state = 0, 1  # state) 1: ruby on, 0: ruby off
     for o in opt:
         if not word[t_s:] or not kana[r_s:]: #文字がない
             break
-        elif o in _s2i.each_together: #ルビとしては使用しない
-            t_end = t_s + _s2i.each_together[o]
-            r_end = r_s + _s2i.each_together[o]
-            rtn.append((False,word[t_s:t_end]))
-        elif o in _s2i.step_by_step: #ルビとしては使用しない
-            t_end = t_s + 1
-            r_end = r_s + _s2i.step_by_step[o]
-            rtn.append((False,word[t_s:t_end]))
+        elif o in _s2i.ruby_on:  # n:m対応でのルビ表示準備
+            slen = _s2i.ruby_on[o] - 1
+            state = 1
+            continue
+        elif o in _s2i.ruby_off:  # n:mでのルビ非表示準備
+            slen = _s2i.ruby_off[o] - 1
+            state = 0
+            continue
         elif _a2z.match(o): #上記以外の文字は無視する
             continue
         elif o == '0': #'0'の時はかなを消費せずに、１文字処理する
             t_end = t_s + 1
             rtn.append((False,word[t_s:t_end]))
-        else: #ルビとして表示する
-            t_end = t_s + 1
+        else:
             r_end = r_s + int(o)
-            rtn.append((True, (word[t_s:t_end], kana[r_s:r_end])))
+            t_end = t_s + 1 + slen
+            if state:  #ルビとして表示する
+                rtn.append((True, (word[t_s:t_end], kana[r_s:r_end])))
+            else:      #ルビとして表示しない
+                rtn.append((False, word[t_s:t_end]))
+            slen, state = 0, 1
 
         #次のループに入る前に位置情報を更新
         t_s, r_s = t_end, r_end
@@ -420,7 +425,14 @@ class ExtIndexUnit(idxr.IndexUnit):
         return terms
 
 
-class ExtIndexEntry(idxr.IndexEntry):
+CODE_UPPER_LIMIT = 3
+
+class ExtConvert(Convert):
+    _main_to_code = {'設定ファイル': 1, 'main': 2, '辞書ファイル': 3, '': 4}
+    _code_to_main = {1: '設定ファイル', 2: 'main', 3: '辞書ファイル', 4: ''}
+
+
+class ExtIndexEntry(ExtConvert, idxr.IndexEntry):
 
     textclass = KanaText
     packclass = ExtSubterm
@@ -449,8 +461,8 @@ class ExtIndexEntry(idxr.IndexEntry):
         index_key = self['index_key']
 
         def _index_unit(term, sub1, sub2):
-            link = self.type2link('uri')
-            emphasis = self.main2code(main)
+            link = self._type2link('uri')
+            emphasis = self._main2code(main)
 
             if not sub1:
                 sub1 = self.textclass('')
@@ -558,7 +570,7 @@ def get_word_list_from_file(config):
     return lines
 
 
-class ExtIndexRack(idxr.IndexRack):
+class ExtIndexRack(ExtConvert, idxr.IndexRack):
     """
     処理概要
 
@@ -583,14 +595,14 @@ class ExtIndexRack(idxr.IndexRack):
 
         # 設定で用意されたかな文字情報の登録
         for rawword in builder.config.kana_text_word_list:
-            entry = ExtIndexEntry(rawword, 'list', 'WORD_LIST', '', 'conf.py', None)  # _cnfpy_
+            entry = ExtIndexEntry(rawword, 'list', 'WORD_LIST', '', '設定ファイル', None)  # _cnfpy_
             index_units = entry.make_index_units()
             for iu in index_units:
                 self.put_in_kana_catalog(iu['main'], iu.get_terms())
 
         # 設定ファイルで用意されたかな文字情報の登録
         for rawword in get_word_list_from_file(builder.config):
-            entry = ExtIndexEntry(rawword, 'list', 'WORD_FILE', '', 'rcfile', None)  # _rncmd_
+            entry = ExtIndexEntry(rawword, 'list', 'WORD_FILE', '', '辞書ファイル', None)  # _rncmd_
             index_units = entry.make_index_units()
             for iu in index_units:
                 self.put_in_kana_catalog(iu['main'], iu.get_terms())
@@ -621,6 +633,11 @@ class ExtIndexRack(idxr.IndexRack):
 
     def put_in_kana_catalog(self, emphasis, terms):
         """KanaText用の処理"""
+
+        # indexディレクティブはカタログに登録しない.
+        if emphasis > CODE_UPPER_LIMIT:
+            return
+
         for term in terms:
             kana, ideo, ruby, spec = term.askana(), term.astext(), term['ruby'], term['option']
             if kana and ideo in self._kana_catalog:
@@ -687,6 +704,11 @@ class ExtIndexRack(idxr.IndexRack):
         super().update_units()
 
     def update_term_with_kana_catalog(self, term):
+        # かな情報がインラインで記載されていれば、それに従う.
+        if term['kana']:
+            return 
+
+        # かな情報がインラインになければカタログから探す.
         if term.astext() in self._kana_catalog:
             term['kana'] = self._kana_catalog[term.astext()][1]
             term['ruby'] = self._kana_catalog[term.astext()][2]
